pub struct CShake128 { /* private fields */ }Expand description
cSHAKE128 hasher.
Implementations
Sourceimpl CShake128
impl CShake128
Sourcepub fn new_with_function_name(
function_name: &[u8],
customization: &[u8],
) -> Self
pub fn new_with_function_name( function_name: &[u8], customization: &[u8], ) -> Self
Creates a new cSHAKE instance with the given function name and customization.
Note that the function name is intended for use by NIST and should only be set to values defined by NIST. You probably don’t need to use this function.